@@ -150,6 +150,11 @@ Q_OBJECT
      */
     int foregroundProcessGroup() const;
 
+    /**
+     * Close the underlying pty master/slave pair.
+     */
+    void closePty();
+
   public slots:
 
     /**
