@@ -676,16 +676,84 @@ void Screen::displayCharacter(wchar_t c)
     // putting the cursor one right to the last column of the screen.
 
     int w = konsole_wcwidth(c);
-    if (w <= 0)
+    if (w < 0)
         return;
+    if (w == 0)
+    {
+        if (QChar(c).category() != QChar::Mark_NonSpacing)
+            return;
+        // Find previous "real character" to try to combine with
+        int charToCombineWithX = qMin(cuX, screenLines[cuY].length());
+        int charToCombineWithY = cuY;
+        bool previousChar = true;
+        do {
+            if (charToCombineWithX > 0)
+            {
+                --charToCombineWithX;
+            }
+            else if (charToCombineWithY > 0 && lineProperties.at(charToCombineWithY - 1) & LINE_WRAPPED)
+            { // Try previous line
+                --charToCombineWithY;
+                charToCombineWithX = screenLines[charToCombineWithY].length() - 1;
+            }
+            else
+            {
+                // Give up
+                previousChar = false;
+                break;
+            }
 
-    if (cuX+w > columns) {
-        if (getMode(MODE_Wrap)) {
+            // Failsafe
+            if (charToCombineWithX < 0)
+            {
+                previousChar = false;
+                break;
+            }
+        } while (screenLines[charToCombineWithY][charToCombineWithX] == 0);
+
+        if (!previousChar)
+        {
+            w = 2;
+            goto notcombine;
+        }
+
+        Character& currentChar = screenLines[charToCombineWithY][charToCombineWithX];
+        if ((currentChar.rendition & RE_EXTENDED_CHAR) == 0)
+        {
+            uint chars[2] = { static_cast<uint>(currentChar.character), static_cast<uint>(c) };
+            currentChar.rendition |= RE_EXTENDED_CHAR;
+            currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars, 2);
+        }
+        else
+        {
+            ushort extendedCharLength;
+            const uint* oldChars = ExtendedCharTable::instance.lookupExtendedChar(currentChar.character, extendedCharLength);
+            Q_ASSERT(oldChars);
+            if (oldChars && extendedCharLength < 8)
+            {
+                Q_ASSERT(extendedCharLength > 1);
+                Q_ASSERT(extendedCharLength < 65535); // redundant due to above check
+                auto chars = std::make_unique<uint[]>(extendedCharLength + 1);
+                std::copy_n(oldChars, extendedCharLength, chars.get());
+                chars[extendedCharLength] = c;
+                currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars.get(), extendedCharLength + 1);
+            }
+        }
+        return;
+    }
+
+notcombine:
+    if (cuX + w > columns)
+    {
+        if (getMode(MODE_Wrap))
+        {
             lineProperties[cuY] = (LineProperty)(lineProperties[cuY] | LINE_WRAPPED);
             nextLine();
         }
         else
+        {
             cuX = columns-w;
+        }
     }
 
     // ensure current line vector has enough elements
