@@ -25,6 +25,7 @@
 
 // Qt
 #include <QRect>
+#include <QSet>
 #include <QTextStream>
 #include <QVarLengthArray>
 
@@ -560,6 +561,23 @@ public:
       */
     static void fillWithDefaultChar(Character* dest, int count);
 
+    QSet<uint> usedExtendedChars() const
+    {
+        QSet<uint> result;
+        for (int i = 0; i < lines; ++i)
+        {
+            const ImageLine &il = screenLines[i];
+            for (int j = 0; j < columns; ++j)
+            {
+                if (il[j].rendition & RE_EXTENDED_CHAR)
+                {
+                    result << il[j].character;
+                }
+            }
+        }
+        return result;
+    }
+
 private:
     Screen(const Screen &) = delete;
     Screen &operator=(const Screen &) = delete;
